summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtextureedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmtextureedit.h')
-rw-r--r--kpovmodeler/pmtextureedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmtextureedit.h b/kpovmodeler/pmtextureedit.h
index 21852ad9..a04b2d93 100644
--- a/kpovmodeler/pmtextureedit.h
+++ b/kpovmodeler/pmtextureedit.h
@@ -39,9 +39,9 @@ class PMTextureEdit : public PMTextureBaseEdit
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMTextureEdit with tqparent and name
*/
- PMTextureEdit( TQWidget* tqparent, const char* name = 0 );
+ PMTextureEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMTextureEdit : public PMTextureBaseEdit
public:
/**
- * Creates a PMTextureEdit with tqparent and name
+ * Creates a PMTextureEdit with parent and name
*/